Learn R Programming

weibulltools (version 2.0.0)

johnson_method: Estimation of Failure Probabilities using Johnson's Method

Description

Soft-deprecated lifecycle

johnson_method() is no longer under active development, switching to estimate_cdf is recommended.

Usage

johnson_method(x, status, id = NULL)

Value

A tibble containing the following columns:

  • id : Identification for every unit.

  • x : Lifetime characteristic.

  • status : Binary data (0 or 1) indicating whether a unit is a right censored observation (= 0) or a failure (= 1).

  • rank : The adjusted ranks.

  • prob : Estimated failure probabilities, NA if status = 0.

  • cdf_estimation_method : Specified method for the estimation of failure probabilities (always 'johnson').

Arguments

x

A numeric vector which consists of lifetime data. Lifetime data could be every characteristic influencing the reliability of a product, e.g. operating time (days/months in service), mileage (km, miles), load cycles.

status

A vector of binary data (0 or 1) indicating whether unit i is a right censored observation (= 0) or a failure (= 1).

id

A vector for the identification of every unit. Default is NULL.

Details

This non-parametric approach is used to estimate the failure probabilities in terms of uncensored or (multiple) right censored data. Compared to complete data the correction is done by calculating adjusted ranks which takes non-defective units into account.

Examples

Run this code
# Vectors:
obs   <- seq(10000, 100000, 10000)
state <- c(0, 1, 1, 0, 0, 0, 1, 0, 1, 0)
uic   <- c("3435", "1203", "958X", "XX71", "abcd", "tz46",
           "fl29", "AX23", "Uy12", "kl1a")

# Example 1 - Johnson method for intact and failed units:
tbl_john <- johnson_method(
  x = obs,
  status = state,
  id = uic
)

# Example 2 - Johnson's method works also if only defective units are considered:
tbl_john_2 <- johnson_method(
  x = obs,
  status = rep(1, length(obs))
)

Run the code above in your browser using DataLab