This function is used to create the layout of a probability plot. It is
called inside of plot_prob to determine the appearance of the
grid with respect to the given characteristic x.
plot_layout(
x,
distribution = c("weibull", "lognormal", "loglogistic", "normal", "logistic", "sev"),
title_main = "Probability Plot",
title_x = "Characteristic",
title_y = "Unreliability",
plot_method = c("plotly", "ggplot2")
)Returns a plot object which contains the layout that is used for probability plotting.
A numeric vector which consists of lifetime data. x is used to
specify the grid of the plot.
Supposed distribution of the random variable.
A character string which is assigned to the main title of the plot.
A character string which is assigned to the title of the x axis.
A character string which is assigned to the title of the y axis.
Package, which is used for generating the plot output.