Learn R Programming

weibulltools (version 2.0.0)

confint_fisher: Fisher's Confidence Bounds for Quantiles and Probabilities

Description

This function computes normal-approximation confidence intervals for quantiles and failure probabilities.

Usage

confint_fisher(x, ...)

# S3 method for wt_model confint_fisher( x, b_lives = c(0.01, 0.1, 0.5), bounds = c("two_sided", "lower", "upper"), conf_level = 0.95, direction = c("y", "x"), ... )

Value

A tibble with class wt_confint containing the following columns:

  • x : An ordered sequence of the lifetime characteristic regarding the failed units, starting at min(x) and ending up at max(x). With b_lives = c(0.01, 0.1, 0.5) the 1%, 10% and 50% quantiles are additionally included in x, but only if the specified probabilities are in the range of the estimated probabilities.

  • prob : An ordered sequence of probabilities with specified b_lives included.

  • std_err : Estimated standard errors with respect to direction.

  • lower_bound : Provided, if bounds is one of "two_sided" or "lower". Lower limit of the confidence region with respect to direction, i.e. quantiles or probabilities.

  • upper_bound : Provided, if bounds is one of "two_sided" or "upper". Upper limit of the confidence region with respect to direction, i.e. quantiles or probabilities.

  • distribution : Specified distribution (determined when calling ml_estimation).

  • bounds : Specified bound(s).

  • direction : Specified direction.

  • cdf_estimation_method : A character that is always NA_character. For the generic visualization functions this column has to be provided.

Arguments

x

Object with classes wt_model and wt_ml_estimation returned from ml_estimation.

...

Further arguments passed to or from other methods. Currently not used.

b_lives

A numeric vector indicating the probabilities p of the \(B_p\)-lives (quantiles) to be considered.

bounds

A character string specifying of which bounds have to be computed. One of "two_sided", "lower" or "upper".

conf_level

Confidence level of the interval.

direction

A character string specifying the direction of the confidence interval. One of "y" (failure probabilities) or "x" (quantiles).

Details

The basis for the calculation of these confidence bounds are the standard errors determined by the delta method and hence the required (log-)location-scale parameters as well as the variance-covariance matrix of these have to be estimated with maximum likelihood.

The bounds on the probability are determined by the z-procedure. See 'References' for more information on this approach.

References

Meeker, William Q; Escobar, Luis A., Statistical methods for reliability data, New York: Wiley series in probability and statistics, 1998

Examples

Run this code
# Reliability data preparation:
## Data for two-parametric model:
data_2p <- reliability_data(
  shock,
  x = distance,
  status = status
)

## Data for three-parametric model:
data_3p <- reliability_data(
  alloy,
  x = cycles,
  status = status
)

# Model estimation with ml_estimation():
ml_2p <- ml_estimation(
  data_2p,
  distribution = "weibull"
)

ml_3p <- ml_estimation(
  data_3p,
  distribution = "lognormal3",
  conf_level = 0.90
)


# Example 1 - Two-sided 95% confidence interval for probabilities ('y'):
conf_fisher_1 <- confint_fisher(
  x = ml_2p,
  bounds = "two_sided",
  conf_level = 0.95,
  direction = "y"
)

# Example 2 - One-sided lower/upper 90% confidence interval for quantiles ('x'):
conf_fisher_2_1 <- confint_fisher(
  x = ml_2p,
  bounds = "lower",
  conf_level = 0.90,
  direction = "x"
)

conf_fisher_2_2 <- confint_fisher(
  x = ml_2p,
  bounds = "upper",
  conf_level = 0.90,
  direction = "x"
)

# Example 3 - Two-sided 90% confidence intervals for both directions using
# a three-parametric model:

conf_fisher_3_1 <- confint_fisher(
  x = ml_3p,
  bounds = "two_sided",
  conf_level = 0.90,
  direction = "y"
)

conf_fisher_3_2 <- confint_fisher(
  x = ml_3p,
  bounds = "two_sided",
  conf_level = 0.90,
  direction = "x"
)

Run the code above in your browser using DataLab